==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/Input/opus/translations/opus_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="49"/>
        <source>Opus Plugin</source>
        <translation>Модуль Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="52"/>
        <source>Ogg Opus Files</source>
        <translation>Файли Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="126"/>
        <source>About Opus Audio Plugin</source>
        <translation>Про модуль аудіо Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="127"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Модуль Opus для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="128"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>Частота</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>Канали</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>Бітрейт</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/opus/translations/opus_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="44"/>
        <source>Opus Plugin</source>
        <translation>Модуль Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="47"/>
        <source>Ogg Opus Files</source>
        <translation>Файли Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="121"/>
        <source>About Opus Audio Plugin</source>
        <translation>Про модуль аудіо Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Модуль Opus для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>Частота</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>Канали</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>Бітрейт</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
</context>
</TS>
